==> feather-2.4.9.tar.gz: feather-2.4.9/RELEASE.md <==
# Release process

- Before a minor release:
  - Update `src/assets/restore_heights_monero_{mainnet,stagenet}.txt`
    - To obtain values, run `contrib/generate-restore-heights/heights.py`
  - Update `m_defaultPools` in `src/widgets/XMRigWidget.h`
  - Update default node lists in `src/assets/nodes.json`
  - Bump `openssl`, `qt`, `tor_*` packages in `contrib/depends/packages`
  - Check all statically linked dependencies for known vulnerabilities using `depends/vulns.py`
  - Rebase on top of latest Monero version
- Update `src/assets/ack.txt`
- Update `SOURCE_DATE_EPOCH` in `contrib/guix/guix-build`
- Update the version number in `CMakeLists.txt`
  - A hardfork-ready release must bump major version
- Create an annotated tag (`git tag x.x.x -a`)
  - Tag must match version in `CMakeLists.txt`
  - Only commits that update the version number in `CMakeLists.txt` may be tagged
- Push the master branch and tags
  - `git push --tags origin master`
- Run `guix` builds in a clean repo:
  - ```bash
    git clone https://github.com/feather-wallet/feather.git
    cd feather
    git checkout <TAG>
    git submodule update --init --recursive
    ./contrib/guix/guix-build
    ```
  - Use at least two machines to verify that the builds are reproducible:
    ```bash
    cd guix-build-x.x.x/output
    find . -type f -not -name "SHA*" -exec sha256sum {} \; | sort -k2
    ```
    - In absence of a system for verified reproduction, at least one machine should be air-gapped.
    - If builds are not reproducible: fix any reproducibility defects and bump patch version. Do not sign or release non-reproducible builds.
     - To quickly identify any non-reproducible `depends` packages:
        ```bash
        cd contrib/depends/built
        find . -name "*.hash" -exec cat {} \; | sort -k2
        ```
- Sign release artifacts and hashlists.
  - Transfer files in `guix-build-x.x.x/output` to release signing machine
  - Run `make-release.sh`
- Update documentation (`feather-wallet/feather-docs`)
- Update the site (`feather-wallet/feather-site`)
  - Add a changelog in `content/changelog`
  - Update the version number, file sizes and paths in `data/release.json`
  - Upload releases, signatures and signed hashlists.
    - Follow the directory structure defined in `MainWindow::onShowUpdateCheck`.
  - Make `depends` source files [available](https://featherwallet.org/files/sources/):
    - `make -C contrib/depends download`
- Announce release on social media (Reddit, Twitter, irc/Matrix)
- Update websocket servers to notify clients of new release
  - Wait up to 7 days to allow for bug reports before major rollout

==> feather-2.6.3.tar.gz: feather-2.6.3/RELEASE.md <==
# Release process

- Before a minor release:
  - Update `src/assets/restore_heights_monero_{mainnet,stagenet}.txt`
    - To obtain values, run `contrib/generate-restore-heights/heights.py`
  - Update `m_defaultPools` in `src/widgets/XMRigWidget.h`
  - Update default node lists in `src/assets/nodes.json`
  - Bump `openssl`, `qt`, `tor_*` packages in `contrib/depends/packages`
  - Update or patch any statically linked dependencies that have known vulnerabilities
    - Run `feather-utils/depends/vulns.py` to check
  - Rebase on top of latest Monero version
- Update `src/assets/ack.txt`
- Update `SOURCE_DATE_EPOCH` in `contrib/guix/guix-build`
- Update the version number in `CMakeLists.txt`
  - A hardfork-ready release must bump major version
- Create an annotated tag (`git tag x.x.x -a`)
  - Tag must match version in `CMakeLists.txt`
  - Only commits that update the version number in `CMakeLists.txt` may be tagged
- Push the master branch and tags
  - `git push --tags origin master`
- Run `guix` builds in a clean repo:
  - ```bash
    git clone https://github.com/feather-wallet/feather.git
    cd feather
    git checkout <TAG>
    git submodule update --init --recursive
    ./contrib/guix/guix-build
    ```
  - Alternatively, run `feather-utils/guix/run-build.sh`
  - Use at least two machines to verify that the builds are reproducible:
    - In absence of a system for verified reproduction, at least one machine should be air-gapped.
    - Use the `feather-utils/guix/compare-builds.sh` script to compare two build directories and identify any reproducibility defects.
    - If builds are not reproducible: fix any reproducibility defects and bump patch version. Do not sign or release non-reproducible builds.
- Sign release artifacts and hashlists.
  - Transfer files in `guix-build-x.x.x/output` to release signing machine
  - Run `feather-utils/release/make-release.sh`
- Update documentation (`feather-wallet/feather-docs`)
- Update the site (`feather-wallet/feather-site`)
  - Run the `feather-utils/site/bump-version.py` script to create a template commit.
  - Edit the changelog in `content/changelog`
    - If a release includes security fixes add "(includes security fixes)" to the title.
  - Update the version number, file sizes and paths in `data/release.json`
  - Upload releases, signatures and signed hashlists.
    - Follow the directory structure defined in `MainWindow::onShowUpdateCheck`.
  - Make `depends` source files [available](https://featherwallet.org/files/sources/):
    - `make -C contrib/depends download`
- Announce release on social media (Reddit, Twitter, irc/Matrix)
- Update websocket servers to notify clients of new release
  - Wait up to 7 days to allow for bug reports before major rollout
